@@ -11,10 +11,13 @@ import csv
 import json
 from statistics import mode
 
+import scripts.parse as parse
 
 
 
-def nwkToAnnotNameNWK(t, j_d, trait, inMeta_name, pangolin, indexToGene, geneToIndex):
+import random
+
+def readInMeta(inMeta_name, pangolin):
 	'''
 	Input: ete3 tree with node names that have 'trait' of clade specified in j_d
 	Outputs: tree with trait appened to node names
@@ -31,19 +34,26 @@ def nwkToAnnotNameNWK(t, j_d, trait, inMeta_name, pangolin, indexToGene, geneToI
 		line_l = re.split('\t|,', line.strip())
 		if strain_index != "NA":
 			tipName = line_l[strain_index]
-			tipDate = line_l[date_index]
+			try:
+				tipDate = line_l[date_index]
+			except:
+				tipDate = ""
 
 			sampDate_d[tipName] = tipDate 
 
 			if tipDate != "":
-				isoDate = date.fromisoformat(tipDate)
+				try:
+					isoDate = date.fromisoformat(tipDate)
 
-				if isoDate < firstDate:
-					firstDate = isoDate
-				if isoDate > lastDate:
-					lastDate = isoDate
+					if isoDate < firstDate:
+						firstDate = isoDate
+					if isoDate > lastDate:
+						lastDate = isoDate
 
-			if pangolin == 'metadata':
+				except ValueError:
+					pass
+
+			if pangolin == 'metadata' and pangolin_index != "NA":
 				sampPangolin = line_l[pangolin_index]
 				sampPangolin_d[tipName] = sampPangolin
 
@@ -56,14 +66,21 @@ def nwkToAnnotNameNWK(t, j_d, trait, inMeta_name, pangolin, indexToGene, geneToI
 			date_index = line_l.index("Date")
 
 		else:
+			print("Metadata must have 'strain' and 'date' OR 'Name' and 'Date' in first line with tab or comma seperated and no spaces. Current col are:")
 			sys.exit(line_l)
 			#"Must have 'strain' and 'date' in first line of tab seperated"
 
 		if pangolin == 'metadata' and pangolin_index == "NA":
 			if "pangolin_lin" in line_l:
 				pangolin_index = line_l.index("pangolin_lin")
-			if "lineage" in line_l:
+			elif "pangolin_lineage" in line_l:
+				pangolin_index = line_l.index("pangolin_lineage")
+			elif "lineage" in line_l:
 				pangolin_index = line_l.index("lineage")
+			else:
+				if sampDate_d == {}: #only print once
+					print("pangolin not found in metadata, col must be called 'pangolin_lin', 'pangolin_lineage', or 'lineage' ")
+
 	
 	if pangolin != 'metadata': # pangolin output lineage report file name
 		inPangolin_open = open(pangolin, "r")
@@ -78,6 +95,9 @@ def nwkToAnnotNameNWK(t, j_d, trait, inMeta_name, pangolin, indexToGene, geneToI
 				tipName = line_l[0]
 				sampPangolin_d[tipName] = sampPangolin
 
+	return(sampDate_d, sampPangolin_d, firstDate, lastDate)
+
+def annotateNwk_nextstrain(t, j_d, trait, sampDate_d, sampPangolin_d, geneToIndex, indexToGene):
 
 	for node in t.traverse("preorder"):
 		if "NODE_" not in node.name:
@@ -91,21 +111,76 @@ def nwkToAnnotNameNWK(t, j_d, trait, inMeta_name, pangolin, indexToGene, geneToI
 
 		if trait == "aa_muts":
 			#for gene in geneToIndex:
-			for index in range(12):
+			for index in range(len(indexToGene)):
 				gene = indexToGene[index]
 				if gene in j_d['nodes'][node.name][trait]:
 					for mut in j_d['nodes'][node.name][trait][gene]:
 						usable = mut.replace(".", "J").replace("-", "X").replace("*", "J") #gaps represented by X
 						temp += usable+"."
 				temp += "-"
+		elif trait == "muts":
+			for mut in j_d['nodes'][node.name][trait]:
+				temp += mut + "."
 		else:
 			temp += str(j_d['nodes'][node.name][trait])
 			#node_annot = temp
 		node.name = node.name + temp
-	return(t, firstDate, lastDate)
+	return(t)
 
 
-def assignToSpecAA(t, mutList, geneToIndex, logNotes_open):
+def treetimeToTraits_d(parseT, traitOfInterstKey):
+	nodeTraits_d = {}
+	if traitOfInterstKey == "aa_muts":
+		traitOfInterstKey = "mutations"
+	for node in parse.traverse_depthFirst(parseT.root):
+		temp = getattr(node, traitOfInterstKey, None)
+		if temp is not None:
+			nodeTraits_d[node.name] = temp
+		else:
+			nodeTraits_d[node.name] = "NA"
+		 	#print("does not have trait", node.__dict__)
+	return nodeTraits_d
+
+
+def annotateNwk_treetime(t, nodeTraits_d, trait, geneBoundry_d, sampDate_d, sampPangolin_d, geneToIndex, indexToGene):
+	
+	for node in t.traverse("preorder"):
+		if "NODE_" not in node.name:
+			if node.name in sampPangolin_d:
+				pID = sampPangolin_d[node.name]
+			else: 
+				pID = "NA"
+			temp = "_" + pID + "_" + sampDate_d[node.name] + "_"
+		else:
+			temp = "_"
+
+		if trait == "aa_muts":
+			mutList = str(nodeTraits_d[node.name])
+			
+			for index in range(12):
+				refGene = indexToGene[index]
+				if refGene in geneBoundry_d:
+					for mutRaw in mutList.split(","):
+						if len(mutRaw) > 2:
+							rawPos = int(mutRaw[1:-1])
+							if rawPos >= geneBoundry_d[refGene][0] and rawPos < geneBoundry_d[refGene][1]:
+								mutRaw.replace(".", "J").replace("-", "X").replace("*", "J")
+								temp += mutRaw[0] + str(rawPos - geneBoundry_d[refGene][0]) + mutRaw[-1] + "."
+				temp += "-"
+			temp += str(nodeTraits_d[node.name])
+			#todo loop through and assign postion in appened aa to genes using renameAln_codingRegions_geneAAboundries.json
+		elif trait == "mutations":
+			for mut in nodeTraits_d[node.name].split(","):
+				temp += mut + "."
+		else:
+			temp += str(nodeTraits_d[node.name])
+		
+			
+		node.name = node.name + temp
+	return(t)
+
+
+def assignToSpecAA(t, mutList, logNotes_open, geneToIndex):
 	'''
 	input: annotated tree (t) and aa mut (mutList) to look for
 	output:
@@ -173,6 +248,65 @@ def assignToSpecAA(t, mutList, geneToIndex, logNotes_open):
 	return(assignment_d, heiarchy_d, clade_s)
 
 
+def assignToNucMut(t, mutList, logNotes_open):
+	'''
+	input: annotated tree (t) and list of nucliotide mut (mutList) to look for
+	output:
+	assignment_d: key: leaf node name; value: clade
+	heierarchy (heiarchy_d: key:child clade; value:parent clade )
+	'''
+	clade_s = set()
+	assignment_d = {}
+	heiarchy_d = {}
+	cladesAssinged_d ={}
+
+	currentClade = 'anc'
+	heiarchy_d['anc'] = 'NA'
+	clade_s.add('anc')
+
+	for node in t.traverse("preorder"):
+		assignment_d[node.name] = currentClade
+
+	for node in t.traverse("preorder"):
+
+		node_name = node.name
+
+		nodeMut_l = node_name.split("_")[-1].split(".")
+		currentClade = assignment_d[node_name]
+
+		mutOfInterst_count = 0
+
+		for mutToFind in mutList:
+			for nodeMut_one in nodeMut_l:
+				if mutToFind[1:-1] == nodeMut_one[1:-1]:
+					if mutToFind[0] == "*" or mutToFind[0] == nodeMut_one[0]:
+						if mutToFind[-1] == "*" or mutToFind[-1] == nodeMut_one[-1]:
+							mutOfInterst_count += 1
+							mutFound = nodeMut_one
+		if mutOfInterst_count == 1:
+			if mutFound not in cladesAssinged_d:
+				cladesAssinged_d[mutFound] = 0
+			cladesAssinged_d[mutFound] += 1
+
+			newClade = mutFound+ "_" + str(cladesAssinged_d[mutFound])
+			clade_s.add(newClade)
+
+			heiarchy_d[newClade] = currentClade
+			assignment_d[node_name] = newClade
+
+			for des_node in node.iter_descendants("postorder"):
+				assignment_d[des_node.name] = newClade
+
+		if mutOfInterst_count > 1:
+			#print("found more than 1 mut of interst", node_name)
+			logNotes_open.write("\n"+"found more than 1 mut of interst"+"\n")
+			logNotes_open.write(node_name+"\n")
+
+
+
+	return(assignment_d, heiarchy_d, clade_s)
+
+
 def assignToTraits(t, ofInterst_l = []):
 	'''
 	input: annotated tree (t) 
@@ -204,7 +338,7 @@ def assignToTraits(t, ofInterst_l = []):
 
 
 			#define new calde because does not match parent
-			if currentClade.split("_")[0] != traitOfNode:
+			if currentClade.split("_")[0] != traitOfNode and traitOfNode != "?":
 				if traitOfNode not in cladesAssinged_d:
 					cladesAssinged_d[traitOfNode] = 0
 				cladesAssinged_d[traitOfNode] += 1
@@ -221,13 +355,12 @@ def assignToTraits(t, ofInterst_l = []):
 	return(assignment_d, heiarchy_d, clade_s)
 
 
-
-
 def assignCladeToLin(assignment_old_d, heiarchy_old_d, clade_old_s):
 	"""
 	mode of Pangolin linage of tips withen clade are appended to clade names
 	"""
 
+
 	reassignCladeNames ={}
 	clade_s = set()
 	assignment_d = {}
@@ -256,6 +389,7 @@ def assignCladeToLin(assignment_old_d, heiarchy_old_d, clade_old_s):
 	for child in heiarchy_old_d:
 		parent = heiarchy_old_d[child]
 		if parent != 'NA':
+
 			heiarchy_d[reassignCladeNames[child]] = reassignCladeNames[parent]
 		else:
 			heiarchy_d[reassignCladeNames[child]] = parent
@@ -269,6 +403,7 @@ def countAbudanceFromNames_byWeek(assignment_d, clade_s, startDate, endDate, del
 	"""
 	counts total number of tips withen each clade, for each time interval (delta) between startDate and endDate 
 	"""
+	psuodocount = 0.1
 	abundances_d = {} # key: week; value: dict of key:clade; value: count
 	weekToDate_d = {}
 	#assignment_d: key: node name; value: clade
@@ -298,32 +433,36 @@ def countAbudanceFromNames_byWeek(assignment_d, clade_s, startDate, endDate, del
 		abundances_d[weekName] = {} 
 
 		for clade in abundances_d[lastWeekName]:
-			abundances_d[weekName][clade] = 1
+			abundances_d[weekName][clade] = psuodocount #change to add psuodocount
+			# if clade == 'anc':
+			# 	abundances_d[weekName][clade] += 1
 
 
 		for tip in assignment_d.keys():
 			if "NODE_" not in tip and "Wuhan" not in tip:
-				tip_date = date.fromisoformat(tip.split("_")[-2])
+				try: 
+					tip_date = date.fromisoformat(tip.split("_")[-2])
 
-				if tip_date < currentEnd and tip_date >= currentStart:
+					if tip_date < currentEnd and tip_date >= currentStart:
 
-					clade = assignment_d[tip]
-					if clade not in abundances_d[weekName]:
-						abundances_d[weekName][clade] = 1
-					abundances_d[weekName][clade] += 1
-					if clade != 'anc':
-						tipNoAnnot = ""
-						for name in tip.split("_")[:-3]: 
-							tipNoAnnot = tipNoAnnot + "_"  + name
-						outLine = "	".join([ weekName, clade, tip, tipNoAnnot[1:]]) + "\n"
-						tipLog_open.write(outLine)
+						clade = assignment_d[tip]
+						if clade not in abundances_d[weekName]:
+							abundances_d[weekName][clade] = psuodocount #change to add psuodocount
+						abundances_d[weekName][clade] += 1
+						if clade != 'anc':
+							tipNoAnnot = ""
+							for name in tip.split("_")[:-3]: 
+								tipNoAnnot = tipNoAnnot + "_"  + name
+							outLine = "	".join([ weekName, clade, tip, tipNoAnnot[1:]]) + "\n"
+							tipLog_open.write(outLine)
+				except ValueError:
+					pass 
 
 
 		currentEnd += delta
 		currentStart += delta
 	tipLog_open.close()
 
-	#print(list(clade_s))
 	noFurtherAbudance = list(clade_s.copy())
 	for weekName in (reversed(week_l)):
 
@@ -331,7 +470,7 @@ def countAbudanceFromNames_byWeek(assignment_d, clade_s, startDate, endDate, del
 		for clade in noFurtherAbudance_last:
 			if clade in abundances_d[weekName]:
 
-				if abundances_d[weekName][clade] == 1 and clade != 'anc':
+				if abundances_d[weekName][clade] == psuodocount: #and clade != 'anc':
 					abundances_d[weekName][clade] = 0
 				else:
 					noFurtherAbudance.remove(clade)
@@ -346,59 +485,49 @@ def main():
 	##########################  parse user arguments
 	parser = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
-	parser.add_argument('-n', '--inNextstrain', required=True, type=str, help="nextstrain results with tree.nwk and [traitOfInterst].json")
-	parser.add_argument('-m', '--inMeta', required=True, type=str, help="metadata tsv with 'strain'	and 'date'cols, optional: cols of trait of interst; and pangolin col named: 'lineage' or 'pangolin_lin'")
-	parser.add_argument('-p', '--inPangolin', required=False, type=str, default = "metadata", help="pangolin output lineage_report.csv file, if argument not supplied looks in inMeta for col with 'pangolin_lin' or 'lineage'")
-
-	parser.add_argument('-f', '--traitOfInterstFile', required=False, type=str, default="aa_muts.json",  help="name of nextstrain [traitOfInterst].json in 'inNextstrain' folder")
-	parser.add_argument('-k', '--traitOfInterstKey', required=False, type=str, default="aa_muts",  help="key for trait of interst in json file")
-	parser.add_argument('-aa', '--aaVOClist', required=False, nargs='+', help="list of aa of interest in form [GENE][*ORAncAA][site][*ORtoAA] ex. S*501*, gaps represed by X")
-
-
-
 	parser.add_argument('-oDir', '--outDirectory', required=False, default ="./", type=str, help="folder for output")
 	parser.add_argument('-oP', '--outPrefix', required=True, type=str, help="prefix of out files withen outDirectory")
 
 
+	treeAndtraits = parser.add_mutually_exclusive_group(required=True)
+	treeAndtraits.add_argument('-n', '--inNextstrain', type=str, help="nextstrain results with tree.nwk and [traitOfInterstFile].json")
+	treeAndtraits.add_argument('-a', '--annotatedTree', type=str, help="nexus file name with annotation: [&!traitOfInterstKey=value], as output by treetime")
+
+
+	parser.add_argument('-m', '--inMeta', required=True, type=str, help="metadata tsv with 'strain'	and 'date'cols, optional: col for  [traitOfInterstKey]; and pangolin col named: 'pangolin_lineage' 'lineage' or 'pangolin_lin'")
+	parser.add_argument('-p', '--inPangolin', required=False, type=str, default = "metadata", help="pangolin output lineage_report.csv file, if argument not supplied looks in inMeta for col with 'pangolin_lineage', 'pangolin_lin', or 'lineage'")
+	parser.add_argument("--noPangolin", action="store_true", help="do not add lineage to clade names")
+
+
+	parser.add_argument('-k', '--traitOfInterstKey', required=False, type=str, default="aa_muts",  help="key for trait of interst in json file OR (if -a/--annotatedTree AND key is mutations with aa (not nuc):  use 'aa_muts')")
+	parser.add_argument('-f', '--traitOfInterstFile', required=False, type=str, default="aa_muts.json",  help="[use with -n/--inNextstrain] name of [traitOfInterstFile].json in '-n/--inNextstrain' folder")
+	parser.add_argument('-g', '--geneBoundry', required=False, type=str, help="[use with -a/--annotatedTree AND -k/--traitOfInterst aa_muts] json formated file specifing start end postions of genes in alignment for annotatedTree  (see example data/geneAAboundries.json)")
+	
+
+	parser.add_argument('-mut', '--VOClist', required=False, nargs='+', help="list of aa of interest in form [GENE][*ORAncAA][site][*ORtoAA] ex. S*501*, gaps represented by X, wild card aa represented by *")
+
 	parser.add_argument('-t', '--timeWindow', required=False, type=str, default="7", help="number of days for sampling window")
 	parser.add_argument('-s', '--startDate', required=False, type=str, default='2020-03-01', help="start date in iso format YYYY-MM-DD or 'firstDate' which is in metadata")
 	parser.add_argument('-e', '--endDate', required=False, type=str, default='lastDate', help="end date in iso format YYYY-MM-DD or 'lastDate' which is in metadata")
 
-	#parser.add_argument('-w', '--MINTIME', required=False, type=str, default="30", help="minimum time point to start plotting")
-	#parser.add_argument('-min', '--MINTOTALCOUNT', required=False, type=str, default="10", help="minimum total count for group to be included")
-
 	
 
 	args = parser.parse_args()
 
 	##########################  file names
 
-	inTree_name = os.path.join(args.inNextstrain, "tree.nwk")
-	
-	
-	inJSON_name = os.path.join(args.inNextstrain, args.traitOfInterstFile)
-	inMeta_name = args.inMeta
-	# if args.inPangolin is None:
-	# 	pangolin = 'metadata'
-	# else:
-	pangolin = args.inPangolin
 	
 	outCladeHierarchy_name = os.path.join(args.outDirectory, args.outPrefix +"_defineCountClades", "cladeHierarchy.csv")
 	outCounts_name = os.path.join(args.outDirectory, args.outPrefix +"_defineCountClades", "abundances.csv")
+	tempTree_name = os.path.join(args.outDirectory, args.outPrefix +"_defineCountClades", "tree.nwk")
 	tipLog_name = os.path.join(args.outDirectory, args.outPrefix +"_defineCountClades", "tipsWithMut.txt")
 
 	logNotes_name = os.path.join(args.outDirectory, args.outPrefix + "_defineCountClades", "log.txt")
 
 
-	# weekTreeFile_folder = os.path.join(args.outDirectory, args.outPrefix+ "_PrunedTrees")
-	# weekTreeFile_prefix = os.path.join(weekTreeFile_folder, "PrunedWeek_")
-
-
-
 	if not os.path.exists(args.outDirectory):
 		os.makedirs(args.outDirectory)
-	# if not os.path.exists(weekTreeFile_folder):
-	#  	os.makedirs(weekTreeFile_folder)
+
 	dataOutDir = os.path.join(args.outDirectory, args.outPrefix + "_defineCountClades")
 	if not os.path.exists(dataOutDir):
 	 	os.makedirs(dataOutDir)
@@ -406,25 +535,86 @@ def main():
 
 	######################### params to referance
 
-	geneToIndex = {"E":0, "M":1, "N":2, "ORF1a":3, "ORF1b":4, "ORF3a":5, "ORF6":6, "ORF7a":7, "ORF7b":8, "ORF8":9, "ORF9b":10, "S":11}
-	indexToGene = {0:"E", 1:"M", 2:"N", 3:"ORF1a", 4:"ORF1b", 5:"ORF3a", 6:"ORF6", 7:"ORF7a", 8:"ORF7b", 9:"ORF8", 10:"ORF9b", 11:"S"}
-
 
 	delta= timedelta(days=int(args.timeWindow))
 
 
-	#########################  load nwk files
-
-	print(inTree_name)
-	if not os.path.exists(inTree_name):
-		sys.exit("missing input tree")
-	t = Tree(inTree_name, format = 3)
-
-
-	j_d = json.load(open(inJSON_name))
+	#########################  load treeAndTraits files
 
+	sampDate_d, sampPangolin_d, firstDate, lastDate = readInMeta(args.inMeta, args.inPangolin)
 	
-	t, firstDate, lastDate = nwkToAnnotNameNWK(t, j_d, args.traitOfInterstKey, inMeta_name, pangolin, indexToGene, geneToIndex)
+	#use nextstrain as input
+	if args.inNextstrain is not None:
+
+		inTree_name = os.path.join(args.inNextstrain, "tree.nwk")
+		print(inTree_name)
+		if not os.path.exists(inTree_name):
+			sys.exit("missing input tree")
+		t = Tree(inTree_name, format = 3)
+
+
+		#annotate tree with ancestral reconstruction
+		inJSON_name = os.path.join(args.inNextstrain, args.traitOfInterstFile)
+		j_d = json.load(open(inJSON_name))
+		
+		# extract all gene names
+		if args.traitOfInterstKey == "aa_muts":
+			i = 0
+			geneToIndex_temp = {}
+			indexToGene_temp = {}
+			for node in j_d['nodes'].keys():
+				for gene in j_d['nodes'][node]["aa_muts"].keys():
+					if gene not in geneToIndex_temp:
+						geneToIndex_temp[gene] = i
+						indexToGene_temp[i] = gene
+						i += 1
+			# global geneToIndex
+			geneToIndex = geneToIndex_temp.copy()
+			# global indexToGene
+			indexToGene = indexToGene_temp.copy()
+		else:
+			geneToIndex = {}
+			indexToGene = {}
+
+		t = annotateNwk_nextstrain(t, j_d, args.traitOfInterstKey, sampDate_d, sampPangolin_d, geneToIndex, indexToGene)
+	#use treetime ancestral as input
+	else: 
+		parseT = parse.treeImport_wrap(args.annotatedTree, ["nexus", "treetimeAnnot"])
+		print(tempTree_name)
+		parse.writeNewick(parseT, tempTree_name, []) #write to file that can be read by ete3
+		t = Tree(tempTree_name, format = 3)
+
+		#annotate tree with ancestral reconstruction
+		if args.traitOfInterstKey=="aa_muts":
+			# extract all gene names
+			if args.geneBoundry is None :
+				sys.exit("geneBoundry json file is required for annotatedTree with aa_muts")
+			else:
+				geneBoundry_d = json.load(open(args.geneBoundry))
+
+				i = 0
+				geneToIndex_temp = {}
+				indexToGene_temp = {}
+				for gene in geneBoundry_d.keys():
+					if gene not in geneToIndex_temp:
+						geneToIndex_temp[gene] = i
+						indexToGene_temp[i] = gene
+						i += 1
+				#global geneToIndex
+				geneToIndex = geneToIndex_temp.copy()
+				#global indexToGene
+				indexToGene = indexToGene_temp.copy()
+		else:
+			geneBoundry_d = {}
+			geneToIndex = {}
+			indexToGene = {}
+
+
+		nodeTraits_d = treetimeToTraits_d(parseT, args.traitOfInterstKey)
+		t = annotateNwk_treetime(t, nodeTraits_d, args.traitOfInterstKey, geneBoundry_d,  sampDate_d, sampPangolin_d, geneToIndex, indexToGene)
+
+
+	######################### make clades assignments (assignment_d: key: leaf node name; value: clade) and heierarchy (heiarchy_d: key:child clade; value:parent clade )
 
 	if args.startDate == "firstDate":
 		startDate = firstDate
@@ -436,34 +626,38 @@ def main():
 		endDate =  date.fromisoformat(args.endDate)	
 
 
-
-	######################### make clades assignments (assignment_d: key: leaf node name; value: clade) and heierarchy (heiarchy_d: key:child clade; value:parent clade )
-
 	logNotes_open = open(logNotes_name, "w")
-	if args.traitOfInterstKey == 'aa_muts':
-		if args.aaVOClist is None:
-			#aa_mut = ['S*501*', 'ORF1b*1183*', 'S*484*', 'S*452*', 'S*681*', 'S*13', 'S*152']
-			#aa_mut = ['S*484*', 'S*501*'] #default sites of interst
-			aa_mut = ["S*484*", "S*501*", "S*13*", "S*452*", "S*477*", "N*205*", "S*253*"]
-			# aa_mut = ["S*484*", "S*501*", "S*13*", "S*452*", "S*477*", "S*253*"]
-			# aa_mut = ['S*484*']
 
+
+	if args.traitOfInterstKey == 'aa_muts':
+		if args.VOClist is None:
+			aa_mut = ["S*484*", "S*501*", "S*13*", "S*452*", "S*477*", "N*205*", "S*253*"]
 		else:
-			aa_mut = args.aaVOClist
+			aa_mut = args.VOClist
 
 		print("\n")
-		print("Searching for muations with:", aa_mut)
+		print("Searching for aa muations with:", aa_mut)
+		logNotes_open.write("\n"+"Searching for aa muations with:"+str(aa_mut)+"\n")
+		assignment_d, heiarchy_d, clade_s = assignToSpecAA(t, aa_mut, logNotes_open, geneToIndex)
+	elif args.traitOfInterstKey == 'mutations' or args.traitOfInterstKey == 'muts':
+		if args.VOClist is None:
+			nuc_mut = ["*23063*", "*22320*"] #mostly for testing purposes 
+		else:
+			nuc_mut = args.VOClist
 
-		
-		logNotes_open.write("\n"+"Searching for muations with:"+str(aa_mut)+"\n")
-
-
-		assignment_d, heiarchy_d, clade_s = assignToSpecAA(t, aa_mut, geneToIndex, logNotes_open)
+		print("\n")
+		print("Searching for muations with:", nuc_mut)
+		logNotes_open.write("\n"+"Searching for muations with:"+str(nuc_mut)+"\n")
+		assignment_d, heiarchy_d, clade_s = assignToNucMut(t, nuc_mut, logNotes_open)
 	else:
+		print("\n"+"Finding clades defined by"+str(args.traitOfInterstKey))
 		logNotes_open.write("\n"+"Finding clades defined by"+str(args.traitOfInterstKey)+"\n")
 		assignment_d, heiarchy_d, clade_s = assignToTraits(t)
 
-	assignment_d, heiarchy_d, clade_s = assignCladeToLin(assignment_d, heiarchy_d, clade_s)
+
+
+	if sampPangolin_d != {} and not args.noPangolin:
+		assignment_d, heiarchy_d, clade_s = assignCladeToLin(assignment_d, heiarchy_d, clade_s)
 
 
 	######################### count abundances based on assignment_d
@@ -498,8 +692,6 @@ def main():
 	outCladeHierarchy_open.close()
 
 
-	#print("FINAL heiarchy_d")
-	#print(heiarchy_d)
 	logNotes_open.write("\n"+"Final heiarchy_d"+"\n")
 	logNotes_open.write(str(heiarchy_d)+"\n")
 
